package cross_variety

import (
	"eta_gn/eta_chart_lib/global"
	"eta_gn/eta_chart_lib/utils"
	"time"
)

// ChartTag
// @Description: chart_tag 图表标签表
type ChartTag struct {
	ChartTagId      int       `orm:"column(chart_tag_id);pk" gorm:"column:chart_tag_id;primaryKey"`
	ChartTagName    string    `description:"标签名称" gorm:"column:chart_tag_name"`
	ChartTagNameEn  string    `description:"标签名称（英文）" gorm:"column:chart_tag_name_en"`
	SysUserId       int       `description:"创建人id" gorm:"column:sys_user_id"`
	SysUserRealName string    `description:"创建人姓名" gorm:"column:sys_user_real_name"`
	ModifyTime      time.Time `description:"修改时间" gorm:"column:modify_time"`
	CreateTime      time.Time `description:"创建时间" gorm:"column:create_time"`
}

// TableName 设置模型对应的表名
func (ChartTag) TableName() string {
	return "chart_tag"
}

// type ChartTag struct {
// 	ChartTagId      int       `orm:"column(chart_tag_id);pk"`
// 	ChartTagName    string    `description:"标签名称"`
// 	ChartTagNameEn  string    `description:"标签名称（英文）"`
// 	SysUserId       int       `description:"创建人id"`
// 	SysUserRealName string    `description:"创建人姓名"`
// 	ModifyTime      time.Time `description:"修改时间"`
// 	CreateTime      time.Time `description:"创建时间"`
// }

// Update
// @Description: 更新标签
// @author: Roc
// @receiver item
// @datetime 2023-11-21 15:15:17
// @param updateColList []string
// @return err error
// func (item *ChartTag) Update(updateColList []string) (err error) {
// 	to := orm.NewOrmUsingDB("data")
// 	_, err = to.Update(item, updateColList...)

// 	return
// }

// Update
// @Description: 更新标签
// @author: Roc
// @receiver item
// @datetime 2023-11-21 15:15:17
// @param updateColList []string
// @return err error
func (item *ChartTag) Update(updateColList []string) (err error) {
	to := global.DmSQL["data"]
	err = to.Model(item).Select(updateColList).Updates(item).Error
	return
}

// Delete 删除
// func (item *ChartTag) Delete() (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Delete(item)
// 	return
// }

func (item *ChartTag) Delete() (err error) {
	o := global.DmSQL["data"]
	err = o.Delete(item).Error
	return
}

// GetTagListByIdList
// @Description: 根据ID列表获取标签列表
// @author: Roc
// @datetime 2023-11-23 17:56:39
// @param idList []int
// @return items []*ChartTag
// @return err error
// func GetTagListByIdList(idList []int) (items []*ChartTag, err error) {
// 	num := len(idList)
// 	if num <= 0 {
// 		return
// 	}
// 	o := orm.NewOrmUsingDB("data")
// 	sql := `SELECT * FROM chart_tag WHERE 1 = 1 AND chart_tag_id in (` + utils.GetOrmInReplace(num) + `)`
// 	_, err = o.Raw(sql, idList).QueryRows(&items)

// 	return
// }

// GetTagListByIdList
// @Description: 根据ID列表获取标签列表
// @author: zqbao
// @datetime 2023-11-23 17:56:39
// @param idList []int
// @return items []*ChartTag
// @return err error
func GetTagListByIdList(idList []int) (items []*ChartTag, err error) {
	num := len(idList)
	if num <= 0 {
		return
	}
	o := global.DmSQL["data"]
	sql := `SELECT * FROM chart_tag WHERE 1 = 1 AND chart_tag_id in (` + utils.GetGormInReplace(num) + `)`
	err = o.Raw(sql, idList).Scan(&items).Error
	return
}
