package models

import (
	"eta_gn/eta_chart_lib/global"
	"eta_gn/eta_chart_lib/utils"
	"fmt"
	"time"
)

// ExcelInfo excel表格详情表
// type ExcelInfo struct {
// 	ExcelInfoId     int       `orm:"column(excel_info_id);pk"`
// 	Source          int       `description:"表格来源，1：excel插件的表格，2：自定义表格，默认：1"`
// 	ExcelType       int       `description:"表格类型，1：指标列，2：日期列，默认：1"`
// 	ExcelName       string    `description:"表格名称"`
// 	UniqueCode      string    `description:"表格唯一编码"`
// 	ExcelClassifyId int       `description:"表格分类id"`
// 	SysUserId       int       `description:"操作人id"`
// 	SysUserRealName string    `description:"操作人真实姓名"`
// 	Content         string    `description:"表格内容"`
// 	ExcelImage      string    `description:"表格图片"`
// 	FileUrl         string    `description:"表格下载地址"`
// 	Sort            int       `description:"排序字段，数字越小越排前面"`
// 	IsDelete        int       `description:"是否删除，0：未删除，1：已删除"`
// 	ModifyTime      time.Time `description:"最近修改日期"`
// 	CreateTime      time.Time `description:"创建日期"`
// }

// ExcelInfo excel表格详情表
type ExcelInfo struct {
	ExcelInfoId     int       `gorm:"column:excel_info_id;primaryKey" description:"表格ID"`
	Source          int       `gorm:"column:source" description:"表格来源，1：excel插件的表格，2：自定义表格，默认：1"`
	ExcelType       int       `gorm:"column:excel_type" description:"表格类型，1：指标列，2：日期列，默认：1"`
	ExcelName       string    `gorm:"column:excel_name" description:"表格名称"`
	UniqueCode      string    `gorm:"column:unique_code" description:"表格唯一编码"`
	ExcelClassifyId int       `gorm:"column:excel_classify_id" description:"表格分类id"`
	SysUserId       int       `gorm:"column:sys_user_id" description:"操作人id"`
	SysUserRealName string    `gorm:"column:sys_user_real_name" description:"操作人真实姓名"`
	Content         string    `gorm:"column:content" description:"表格内容"`
	ExcelImage      string    `gorm:"column:excel_image" description:"表格图片"`
	FileUrl         string    `gorm:"column:file_url" description:"表格下载地址"`
	Sort            int       `gorm:"column:sort" description:"排序字段，数字越小越排前面"`
	IsDelete        int       `gorm:"column:is_delete" description:"是否删除，0：未删除，1：已删除"`
	ModifyTime      time.Time `gorm:"column:modify_time" description:"最近修改日期"`
	CreateTime      time.Time `gorm:"column:create_time" description:"创建日期"`
}

func (e *ExcelInfo) TableName() string {
	return "excel_info"
}

// Update 更新 excel表格基础信息
func (excelInfo *ExcelInfo) Update(cols []string) (err error) {
	o := global.DmSQL["data"]
	err = o.Model(excelInfo).Select(cols).Updates(excelInfo).Error
	return
}

// Update 更新 excel表格基础信息
// func (excelInfo *ExcelInfo) Update(cols []string) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Update(excelInfo, cols...)
// 	return
// }

//	type MyExcelInfoList struct {
//		ExcelInfoId     int       `orm:"column(excel_info_id);pk"`
//		ExcelName       string    `description:"表格名称"`
//		UniqueCode      string    `description:"表格唯一编码"`
//		ExcelClassifyId int       `description:"表格分类id"`
//		SysUserId       int       `description:"操作人id"`
//		SysUserRealName string    `description:"操作人真实姓名"`
//		ExcelImage      string    `description:"表格图片"`
//		FileUrl         string    `description:"表格下载地址"`
//		Sort            int       `description:"排序字段，数字越小越排前面"`
//		ModifyTime      time.Time `description:"最近修改日期"`
//		CreateTime      time.Time `description:"创建日期"`
//	}
type MyExcelInfoList struct {
	ExcelInfoId     int       `gorm:"column:excel_info_id;primaryKey" description:"表格ID" orm:"column(excel_info_id);pk"`
	ExcelName       string    `gorm:"column:excel_name" description:"表格名称"`
	UniqueCode      string    `gorm:"column:unique_code" description:"表格唯一编码"`
	ExcelClassifyId int       `gorm:"column:excel_classify_id" description:"表格分类id"`
	SysUserId       int       `gorm:"column:sys_user_id" description:"操作人id"`
	SysUserRealName string    `gorm:"column:sys_user_real_name" description:"操作人真实姓名"`
	ExcelImage      string    `gorm:"column:excel_image" description:"表格图片"`
	FileUrl         string    `gorm:"column:file_url" description:"表格下载地址"`
	Sort            int       `gorm:"column:sort" description:"排序字段，数字越小越排前面"`
	ModifyTime      time.Time `gorm:"column:modify_time" description:"最近修改日期"`
	CreateTime      time.Time `gorm:"column:create_time" description:"创建日期"`
}

// AddExcelInfo 新增表格
func AddExcelInfo(excelInfo *ExcelInfo) (err error) {
	o := global.DmSQL["data"]
	// 表格信息入库
	err = o.Create(excelInfo).Error
	return
}

// EditExcelInfo 编辑表格
func EditExcelInfo(excelInfo *ExcelInfo, updateExcelInfoParams []string) (err error) {
	o := global.DmSQL["data"]
	// ETA表格信息变更
	err = o.Model(excelInfo).Select(updateExcelInfoParams).Updates(excelInfo).Error
	return
}

// GetExcelInfoById 根据id 获取eta表格详情
func GetExcelInfoById(excelInfoId int) (item *ExcelInfo, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE excel_info_id=? AND is_delete=0 `
	err = o.Raw(sql, excelInfoId).First(&item).Error
	return
}

func GetExcelInfoViewById(excelInfoId int) (item *ExcelInfoView, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE excel_info_id=? AND is_delete=0 `
	err = o.Raw(sql, excelInfoId).First(&item).Error
	return
}

func GetExcelInfoCountByCondition(condition string, pars []interface{}) (count int, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT COUNT(1) AS count FROM excel_info WHERE 1=1 AND is_delete=0 `
	if condition != "" {
		sql += condition
	}
	err = o.Raw(sql, pars...).Scan(&count).Error
	return
}

func GetExcelInfoByCondition(condition string, pars []interface{}) (item *ExcelInfo, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE 1=1 AND is_delete=0 `
	if condition != "" {
		sql += condition
	}
	err = o.Raw(sql, pars...).First(&item).Error
	return
}

// GetNextExcelInfo 根据分类id获取下一个excel表格
func GetNextExcelInfo(classifyId int) (item *ExcelInfo, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT b.* FROM excel_classify AS a
			INNER JOIN excel_info AS b ON a.excel_classify_id=b.excel_classify_id
			WHERE a.excel_classify_id>? AND is_delete=0
			ORDER BY a.excel_classify_id ASC
			LIMIT 1 `
	err = o.Raw(sql, classifyId).First(&item).Error
	return
}

// EditExcelInfoImage 修改excel表格的图片
func EditExcelInfoImage(excelInfoId int, imageUrl string) (err error) {
	o := global.DmSQL["data"]

	sql := ` UPDATE  excel_info SET excel_image=?, modify_time = NOW() WHERE excel_info_id = ? AND is_delete=0 `
	err = o.Exec(sql, imageUrl, excelInfoId).Error
	if err != nil {
		fmt.Println("EditExcelInfoImage Err:", err.Error())
		return err
	}

	return
}

// GetExcelInfoByUniqueCode 根据unique_code来获取excel表格详情
func GetExcelInfoByUniqueCode(uniqueCode string) (item *ExcelInfoView, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE unique_code=? AND is_delete=0 `
	err = o.Raw(sql, uniqueCode).First(&item).Error
	return
}

// GetFirstExcelInfoByClassifyId 获取当前分类下，且排序数相同 的排序第一条的数据
func GetFirstExcelInfoByClassifyId(classifyId int) (item *ExcelInfo, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE excel_classify_id=? AND is_delete=0 order by sort asc,excel_info_id asc limit 1`
	err = o.Raw(sql, classifyId).First(&item).Error
	return
}

// UpdateExcelInfoSortByClassifyId 根据表格id更新排序
func UpdateExcelInfoSortByClassifyId(classifyId, nowSort, prevExcelInfoId int, updateSort string) (err error) {
	o := global.DmSQL["data"]
	sql := ` update excel_info set sort = ` + updateSort + ` WHERE excel_classify_id=? and sort > ? AND is_delete=0 `
	if prevExcelInfoId > 0 {
		sql += ` or (excel_info_id > ` + fmt.Sprint(prevExcelInfoId) + ` and sort = ` + fmt.Sprint(nowSort) + `)`
	}
	err = o.Exec(sql, classifyId, nowSort).Error
	return
}

// AddExcelInfo 新增表格
// func AddExcelInfo(excelInfo *ExcelInfo) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	// 表格信息入库
// 	lastId, err := o.Insert(excelInfo)
// 	if err != nil {
// 		return
// 	}
// 	excelInfo.ExcelInfoId = int(lastId)
// 	return
// }

// // EditExcelInfo 编辑表格
// func EditExcelInfo(excelInfo *ExcelInfo, updateExcelInfoParams []string) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	// ETA表格信息变更
// 	_, err = o.Update(excelInfo, updateExcelInfoParams...)
// 	return
// }

// // GetExcelInfoById 根据id 获取eta表格详情
// func GetExcelInfoById(excelInfoId int) (item *ExcelInfo, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE excel_info_id=? AND is_delete=0 `
// 	err = o.Raw(sql, excelInfoId).QueryRow(&item)
// 	return
// }

// func GetExcelInfoViewById(excelInfoId int) (item *ExcelInfoView, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE excel_info_id=? AND is_delete=0 `
// 	err = o.Raw(sql, excelInfoId).QueryRow(&item)
// 	return
// }

// func GetExcelInfoCountByCondition(condition string, pars []interface{}) (count int, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT COUNT(1) AS count FROM excel_info WHERE 1=1 AND is_delete=0 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	err = o.Raw(sql, pars).QueryRow(&count)
// 	return
// }

// func GetExcelInfoByCondition(condition string, pars []interface{}) (item *ExcelInfo, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE 1=1 AND is_delete=0 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	err = o.Raw(sql, pars).QueryRow(&item)
// 	return
// }

// // GetNextExcelInfo 根据分类id获取下一个excel表格
// func GetNextExcelInfo(classifyId int) (item *ExcelInfo, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT b.* FROM excel_classify AS a
// 			INNER JOIN excel_info AS b ON a.excel_classify_id=b.excel_classify_id
// 			WHERE a.excel_classify_id>? AND is_delete=0
// 			ORDER BY a.excel_classify_id ASC
// 			LIMIT 1 `
// 	err = o.Raw(sql, classifyId).QueryRow(&item)
// 	return
// }

// // EditExcelInfoImage 修改excel表格的图片
// func EditExcelInfoImage(excelInfoId int, imageUrl string) (err error) {
// 	o := orm.NewOrmUsingDB("data")

// 	sql := ` UPDATE  excel_info SET excel_image=?, modify_time = NOW() WHERE excel_info_id = ? AND is_delete=0 `
// 	_, err = o.Raw(sql, imageUrl, excelInfoId).Exec()
// 	if err != nil {
// 		fmt.Println("EditExcelInfoImage Err:", err.Error())
// 		return err
// 	}

// 	return
// }

// // GetExcelInfoByUniqueCode 根据unique_code来获取excel表格详情
// func GetExcelInfoByUniqueCode(uniqueCode string) (item *ExcelInfoView, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE unique_code=? AND is_delete=0 `
// 	err = o.Raw(sql, uniqueCode).QueryRow(&item)
// 	return
// }

// // GetFirstExcelInfoByClassifyId 获取当前分类下，且排序数相同 的排序第一条的数据
// func GetFirstExcelInfoByClassifyId(classifyId int) (item *ExcelInfo, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE excel_classify_id=? AND is_delete=0 order by sort asc,excel_info_id asc limit 1`
// 	err = o.Raw(sql, classifyId).QueryRow(&item)
// 	return
// }

// // UpdateExcelInfoSortByClassifyId 根据表格id更新排序
// func UpdateExcelInfoSortByClassifyId(classifyId, nowSort, prevExcelInfoId int, updateSort string) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` update excel_info set sort = ` + updateSort + ` WHERE excel_classify_id=? and sort > ? AND is_delete=0 `
// 	if prevExcelInfoId > 0 {
// 		sql += ` or (excel_info_id > ` + fmt.Sprint(prevExcelInfoId) + ` and sort = ` + fmt.Sprint(nowSort) + `)`
// 	}
// 	_, err = o.Raw(sql, classifyId, nowSort).Exec()
// 	return
// }

//	type ExcelInfoView struct {
//		ExcelInfoId     int       `orm:"column(excel_info_id);pk"`
//		Source          int       `description:"表格来源，1：excel插件的表格，2：自定义表格，默认：1"`
//		ExcelType       int       `description:"表格类型，1：指标列，2：日期列，默认：1"`
//		ExcelName       string    `description:"表格名称"`
//		UniqueCode      string    `description:"表格唯一编码"`
//		ExcelClassifyId int       `description:"表格分类id"`
//		SysUserId       int       `description:"操作人id"`
//		SysUserRealName string    `description:"操作人真实姓名"`
//		Content         string    `description:"表格内容"`
//		ExcelImage      string    `description:"表格图片"`
//		FileUrl         string    `description:"表格下载地址"`
//		Sort            int       `description:"排序字段，数字越小越排前面"`
//		IsDelete        int       `description:"是否删除，0：未删除，1：已删除" json:"-"`
//		ModifyTime      time.Time `description:"最近修改日期"`
//		CreateTime      time.Time `description:"创建日期"`
//		SourcesFrom     string    `description:"图表来源"`
//	}
type ExcelInfoView struct {
	ExcelInfoId     int       `gorm:"column:excel_info_id;primaryKey" description:"表格ID" orm:"column(excel_info_id);pk"`
	Source          int       `gorm:"column:source" description:"表格来源，1：excel插件的表格，2：自定义表格，默认：1"`
	ExcelType       int       `gorm:"column:excel_type" description:"表格类型，1：指标列，2：日期列，默认：1"`
	ExcelName       string    `gorm:"column:excel_name" description:"表格名称"`
	UniqueCode      string    `gorm:"column:unique_code" description:"表格唯一编码"`
	ExcelClassifyId int       `gorm:"column:excel_classify_id" description:"表格分类id"`
	SysUserId       int       `gorm:"column:sys_user_id" description:"操作人id"`
	SysUserRealName string    `gorm:"column:sys_user_real_name" description:"操作人真实姓名"`
	Content         string    `gorm:"column:content" description:"表格内容"`
	ExcelImage      string    `gorm:"column:excel_image" description:"表格图片"`
	FileUrl         string    `gorm:"column:file_url" description:"表格下载地址"`
	Sort            int       `gorm:"column:sort" description:"排序字段，数字越小越排前面"`
	IsDelete        int       `gorm:"column:is_delete" description:"是否删除，0：未删除，1：已删除" json:"-"`
	ModifyTime      time.Time `gorm:"column:modify_time" description:"最近修改日期"`
	CreateTime      time.Time `gorm:"column:create_time" description:"创建日期"`
	SourcesFrom     string    `gorm:"column:sources_from" description:"图表来源"`
}

// GetExcelInfoByClassifyIdAndName 根据分类id和表格名获取表格信息
func GetExcelInfoByClassifyIdAndName(classifyId int, excelName string) (item *ExcelInfo, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE excel_classify_id = ? and excel_name=? AND is_delete=0 `
	err = o.Raw(sql, classifyId, excelName).First(&item).Error
	return
}

// GetExcelInfoListByUniqueCodeSlice 根据表格编码获取表格列表数据
func GetExcelInfoListByUniqueCodeSlice(uniqueCodeSlice []string) (total int64, items []*ExcelInfo, err error) {
	num := len(uniqueCodeSlice)
	if num <= 0 {
		return
	}
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE unique_code in ("` + utils.GetGormInReplace(num) + `") AND is_delete=0 `
	err = o.Raw(sql, uniqueCodeSlice).Scan(&items).Error
	total = int64(len(items))
	return
}

// GetExcelListByCondition 获取excel表格列表数据
func GetExcelListByCondition(condition string, pars []interface{}, startSize, pageSize int) (item []*MyExcelInfoList, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE 1=1 AND is_delete=0 `
	if condition != "" {
		sql += condition
	}
	//sql += " ORDER BY sort ASC,chart_info_id DESC LIMIT ?,? "
	sql += " ORDER BY create_time DESC LIMIT ?,? "
	pars = append(pars, startSize, pageSize)
	err = o.Raw(sql, pars...).Scan(&item).Error
	return
}

// GetNoContentExcelListByCondition 获取没有content的excel表格列表数据
func GetNoContentExcelListByCondition(condition string, pars []interface{}, startSize, pageSize int) (item []*MyExcelInfoList, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT excel_info_id,excel_name,unique_code,excel_classify_id,sys_user_id,sys_user_real_name,excel_image,file_url,sort,create_time,modify_time
FROM excel_info WHERE 1=1 AND is_delete=0 `
	if condition != "" {
		sql += condition
	}
	//sql += " ORDER BY sort ASC,chart_info_id DESC LIMIT ?,? "
	sql += " ORDER BY create_time DESC LIMIT ?,? "
	pars = append(pars, startSize, pageSize)
	err = o.Raw(sql, pars...).Scan(&item).Error
	return
}

func GetExcelListCountByCondition(condition string, pars []interface{}) (count int, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT COUNT(1) AS count FROM excel_info WHERE 1=1 AND is_delete=0 `
	if condition != "" {
		sql += condition
	}
	err = o.Raw(sql, pars...).Scan(&count).Error
	return
}

// GetExcelViewInfoByExcelInfoId 根据excelInfoId 获取ETA表格详情
func GetExcelViewInfoByExcelInfoId(excelInfoId int) (item *MyExcelInfoList, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE excel_info_id = ? AND is_delete=0 `
	err = o.Raw(sql, excelInfoId).First(&item).Error
	return
}

// GetExcelInfoCountByClassifyId 根据分类id获取名下表格数量
func GetExcelInfoCountByClassifyId(classifyId int) (total int64, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT count(1) total FROM excel_info WHERE excel_classify_id = ? AND is_delete=0 `
	err = o.Raw(sql, classifyId).Scan(&total).Error
	return
}

func GetExcelInfoListByCondition(condition string, pars []interface{}) (items []*ExcelInfo, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT * FROM excel_info WHERE 1=1 AND is_delete=0 `
	if condition != "" {
		sql += condition
	}
	sql += ` ORDER BY sort asc, excel_info_id asc`
	err = o.Raw(sql, pars...).Scan(&items).Error
	return
}

// GetExcelInfoByClassifyIdAndName 根据分类id和表格名获取表格信息
// func GetExcelInfoByClassifyIdAndName(classifyId int, excelName string) (item *ExcelInfo, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE excel_classify_id = ? and excel_name=? AND is_delete=0 `
// 	err = o.Raw(sql, classifyId, excelName).QueryRow(&item)
// 	return
// }

// // GetExcelInfoListByUniqueCodeSlice 根据表格编码获取表格列表数据
// func GetExcelInfoListByUniqueCodeSlice(uniqueCodeSlice []string) (total int64, items []*ExcelInfo, err error) {
// 	num := len(uniqueCodeSlice)
// 	if num <= 0 {
// 		return
// 	}
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE unique_code in ("` + utils.GetOrmInReplace(num) + `") AND is_delete=0 `
// 	total, err = o.Raw(sql, uniqueCodeSlice).QueryRows(&items)
// 	return
// }

// // GetExcelListByCondition 获取excel表格列表数据
// func GetExcelListByCondition(condition string, pars []interface{}, startSize, pageSize int) (item []*MyExcelInfoList, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE 1=1 AND is_delete=0 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	//sql += " ORDER BY sort ASC,chart_info_id DESC LIMIT ?,? "
// 	sql += " ORDER BY create_time DESC LIMIT ?,? "
// 	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&item)
// 	return
// }

// // GetNoContentExcelListByCondition 获取没有content的excel表格列表数据
// func GetNoContentExcelListByCondition(condition string, pars []interface{}, startSize, pageSize int) (item []*MyExcelInfoList, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT excel_info_id,excel_name,unique_code,excel_classify_id,sys_user_id,sys_user_real_name,excel_image,file_url,sort,create_time,modify_time
// FROM excel_info WHERE 1=1 AND is_delete=0 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	//sql += " ORDER BY sort ASC,chart_info_id DESC LIMIT ?,? "
// 	sql += " ORDER BY create_time DESC LIMIT ?,? "
// 	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&item)
// 	return
// }

// func GetExcelListCountByCondition(condition string, pars []interface{}) (count int, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT COUNT(1) AS count FROM excel_info WHERE 1=1 AND is_delete=0 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	err = o.Raw(sql, pars).QueryRow(&count)
// 	return
// }

// // GetExcelViewInfoByExcelInfoId 根据excelInfoId 获取ETA表格详情
// func GetExcelViewInfoByExcelInfoId(excelInfoId int) (item *MyExcelInfoList, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE excel_info_id = ? AND is_delete=0 `
// 	err = o.Raw(sql, excelInfoId).QueryRow(&item)
// 	return
// }

// // GetExcelInfoCountByClassifyId 根据分类id获取名下表格数量
// func GetExcelInfoCountByClassifyId(classifyId int) (total int64, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT count(1) total FROM excel_info WHERE excel_classify_id = ? AND is_delete=0 `
// 	err = o.Raw(sql, classifyId).QueryRow(&total)
// 	return
// }

// func GetExcelInfoListByCondition(condition string, pars []interface{}) (items []*ExcelInfo, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT * FROM excel_info WHERE 1=1 AND is_delete=0 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	sql += ` ORDER BY sort asc, excel_info_id asc`
// 	_, err = o.Raw(sql, pars).QueryRows(&items)
// 	return
// }
